@@ -6,8 +6,7 @@ import numpy as np
 import math as math
 from adjustText import adjust_text
 
-from . import pj
-# from . import tree
+from . import tree
 from . import per
 from . import des
 from . import notes
